import { __decorate, __metadata, __param } from "tslib";
import * as Path from 'path';
import { buildConfigSchema, resolveBoilerplateModule, resolveMagicspaceBoilerplateConfig, } from '@magicspace/core';
import { Command, ExpectedError, command, metadata, param } from 'clime';
import FSExtra from 'fs-extra';
import { CommonOptions } from '../@command.js';
import { CONFIG_SCHEMA_FILE_NAME } from '../@constants.js';
let default_1 = class extends Command {
    async execute(projectDir, options) {
        const magicspaceDir = Path.resolve(projectDir, options.magicspace);
        const { module: configExport } = await resolveMagicspaceBoilerplateConfig(magicspaceDir);
        if (Array.isArray(configExport)) {
            throw new ExpectedError('JSON schema update is not supported for multi-boilerplate config');
        }
        const { boilerplate } = configExport;
        const { Options } = await resolveBoilerplateModule(boilerplate, magicspaceDir);
        if (Options) {
            const configSchemaPath = Path.join(magicspaceDir, CONFIG_SCHEMA_FILE_NAME);
            await FSExtra.outputFile(configSchemaPath, JSON.stringify(buildConfigSchema(Options), undefined, 2));
            return 'JSON schema updated.';
        }
        else {
            return `Options X-Type is not defined for boilerplate ${JSON.stringify(boilerplate)}`;
        }
    }
};
__decorate([
    metadata,
    __param(0, param({
        default: '.',
    })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, CommonOptions]),
    __metadata("design:returntype", Promise)
], default_1.prototype, "execute", null);
default_1 = __decorate([
    command({
        description: 'Update magicspace config schema',
    })
], default_1);
export default default_1;
//# sourceMappingURL=update-schema.js.map